# Créé le Sat Apr  2 12:47:38 2022
# @auteur: David ALBERTO (www.astrolabe-science.fr)

import matplotlib.pyplot as plt
from skyfield.api import load
import locale# noms des mois en français

annee=2022
taille_texte=8

plt.rcParams["font.family"] = "Roboto"#ou autre police installée

locale.setlocale(locale.LC_ALL, 'fr_FR.UTF-8')#dates en français

ts = load.timescale()#création d'une échelle de temps pour repérer les dates avec Skyfield
planets = load('de421.bsp')#chargement d'un fichier d'éphémérides (1900-2050)
# planets = load('de430_1850-2150.bsp')# fichier d'éphémérides (1850-2150)
earth = planets['earth']
sun = planets['sun']

# Fonction retournant la déclinaison du Soleil pour une date:
def declin(date):
    ra, dec, distance = earth.at(date).observe(sun).apparent().radec(epoch='date')
    declinaison=dec.degrees
    declinaison=str(round(declinaison, 2)).replace('.', ',')#arrondi avec virgule décimale
    return declinaison
# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# Paramètres du graphique :

fig, axs=plt.subplots(nrows=2, ncols=6, tight_layout=True)#création d'une figure et de 12 axes (1 par mois)
#Les graphes forment une grille de 2 lignes et 6 colonnes
#on peut modifier le nombre de grilles et colonnes, pourvu que le produit fasse 12.
axs=axs.flatten()#pour itérer sur les axes avec axs[N]
fig.set_size_inches(21/2.54, 29.7/2.54)#dimensions de la figure, en pouces
"""
En modifiant les dimensions de la figure, il faudra ajuster :
- la taille de la police
- les limites des axes en x et en y
Et réciproquement.
"""
plt.suptitle("Déclinaison du Soleil en %s"%(annee), fontsize=17, color='royalblue',
             fontweight='bold')

# %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
# Mise en forme des graphiques mensuels :
for N in range(1, 12+1):#N : numéro du mois courant, de 1 à 12
    ax=axs[N-1]
    nom_mois = ts.utc(annee,N,1).utc_strftime("%B")
    ax.set_title(nom_mois, fontsize=13, c='blueviolet')#nom complet du mois
    ax.set_xticks([])#suppression des graduations
    ax.set_yticks([])#suppression des graduations
    ax.set_ylim(0, 32)#hauteur suffisante pour les listes de dates
    ax.invert_yaxis()#inversion de l'axe y, pour l'affichage des jours de haut en bas
    ax.set_xlim(-0.04, 0.4)#largeur suffisante pour le texte, à adapter à la police

# Parcourir tous les jours de l'année, jusqu'au 31 décembre inclus
jour=ts.utc(annee,1,1)
while jour != ts.utc(annee,12,31)+1:
    N_jour = int(jour.utc_strftime("%d"))
    N_mois = int(jour.utc_strftime("%m"))
    texte1 = jour.utc_strftime("%d %b")#date abrégée
    texte2 = declin(jour)#déclinaison du jour
    axs[N_mois-1].text(0,N_jour,texte1, fontsize=taille_texte,fontweight='bold')
    axs[N_mois-1].text(0.2,N_jour,texte2, fontsize=taille_texte)
    jour = jour+1

fig.text(0.01,0.005,"D. Alberto (www.astrolabe-science.fr)",fontsize=6)
NomFichier="DeclinaisonSoleil_"+str(annee)
fig.savefig(NomFichier+".png", dpi=200)#création d'un fichier image PNG
fig.savefig(NomFichier+".pdf")#création d'un fichier PDF
# plt.show()
